@@ -97,10 +97,50 @@ BaseColorMapPlotCompositeWidget::createMainMenu()
   // integrations. We do not support the stuffing more than one color map into a
   // color map plot, contrary to what we do with graphs.
 
-  mp_mainMenu->addSeparator();
+  // Complete the export/save menu item list with the color map specific menu
+  // item.
+
+  QAction *save_matrix_to_text_file_p =
+    new QAction("Save matrix as 3 columns to text file", this);
+  save_matrix_to_text_file_p->setStatusTip(
+    tr("Save matrix as 3 columns to text file"));
+  save_matrix_to_text_file_p->setShortcut(QKeySequence("Ctrl+M, C"));
+
+  connect(save_matrix_to_text_file_p, &QAction::triggered, [this]() {
+    saveMatrixAs3ColumnsToTextFile();
+  });
+
+  mp_mainMenu->addAction(save_matrix_to_text_file_p);
+
+  save_matrix_to_text_file_p =
+    new QAction("Save matrix as a matrix to text file", this);
+  save_matrix_to_text_file_p->setStatusTip(
+    tr("Save matrix as a matrix to text file"));
+  save_matrix_to_text_file_p->setShortcut(QKeySequence("Ctrl+M, M"));
+
+  connect(save_matrix_to_text_file_p, &QAction::triggered, [this]() {
+    saveMatrixAsMatrixToTextFile(false);
+  });
+
+  mp_mainMenu->addAction(save_matrix_to_text_file_p);
+
+  save_matrix_to_text_file_p =
+    new QAction("Save matrix as a detailed matrix to text file", this);
+  save_matrix_to_text_file_p->setStatusTip(
+    tr("Save matrix as a detailed matrix to text file"));
+  save_matrix_to_text_file_p->setShortcut(QKeySequence("Ctrl+M, D"));
+
+  connect(save_matrix_to_text_file_p, &QAction::triggered, [this]() {
+    saveMatrixAsMatrixToTextFile(true);
+  });
+
+  mp_mainMenu->addAction(save_matrix_to_text_file_p);
+
 
   // An now append new ColorMap-specific menu
 
+  mp_mainMenu->addSeparator();
+
   // The axes transposition.
   QAction *transpose_axes_p = new QAction("Transpose axes", this);
   transpose_axes_p->setStatusTip(tr("Transpose axes"));
@@ -315,6 +355,93 @@ BaseColorMapPlotCompositeWidget::yAxisKind() const
     ->yAxisDataKind();
 }
 
+bool
+BaseColorMapPlotCompositeWidget::saveMatrixAs3ColumnsToTextFile()
+{
+  QString fileName =
+    QFileDialog::getSaveFileName(this,
+                                 tr("Select a file to save the matrix into"),
+                                 QDir::home().absolutePath());
+
+  if(fileName.isEmpty())
+    {
+      qDebug() << "The file name to write the data into is empty!";
+      return false;
+    }
+
+  QFile file(fileName);
+
+  if(!file.open(QIODevice::WriteOnly | QIODevice::Text))
+    {
+      QMessageBox::information(
+        this,
+        "Please select a writable destination file for the data export",
+        "The file name provided points to a file that is not writable.",
+        QMessageBox::StandardButton::Ok,
+        QMessageBox::StandardButton::NoButton);
+
+      return false;
+    }
+
+  QString matrix_string;
+
+  static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
+    ->dataTo3ColString(matrix_string);
+
+  QTextStream outStream(&file);
+
+  outStream << matrix_string;
+  outStream.flush();
+
+  file.close();
+
+  return true;
+}
+
+
+bool
+BaseColorMapPlotCompositeWidget::saveMatrixAsMatrixToTextFile(bool detailed)
+{
+  QString fileName =
+    QFileDialog::getSaveFileName(this,
+                                 tr("Select a file to save the matrix into"),
+                                 QDir::home().absolutePath());
+
+  if(fileName.isEmpty())
+    {
+      qDebug() << "The file name to write the data into is empty!";
+      return false;
+    }
+
+  QFile file(fileName);
+
+  if(!file.open(QIODevice::WriteOnly | QIODevice::Text))
+    {
+      QMessageBox::information(
+        this,
+        "Please select a writable destination file for the data export",
+        "The file name provided points to a file that is not writable.",
+        QMessageBox::StandardButton::Ok,
+        QMessageBox::StandardButton::NoButton);
+
+      return false;
+    }
+
+  QString matrix_string;
+
+  static_cast<pappso::BaseColorMapPlotWidget *>(mp_plotWidget)
+    ->dataToMatrixString(matrix_string, detailed);
+
+  QTextStream outStream(&file);
+
+  outStream << matrix_string;
+  outStream.flush();
+
+  file.close();
+
+  return true;
+}
+
 
 } // namespace minexpert
 
