@@ -816,8 +816,6 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
   const ProcessingFlow &processing_flow =
     getProcessingFlowForPlottable(source_plottable_p);
 
-  const ProcessingStep *processing_step_p = processing_flow.mostRecentStep();
-
   MsFragmentationSpec ms_fragmentation_spec;
 
   // Ask that only steps having a valid MsFragmentationSpec instance be
@@ -850,7 +848,7 @@ BasePlotCompositeWidget::showMsFragmentationSpecDlg()
       // There was/were indeed step instances with a valid ms
       // fragmentation spec. Arbitrarily select the last one.
 
-      processing_step_p     = processing_steps.back();
+      const ProcessingStep *processing_step_p = processing_steps.back();
       ms_fragmentation_spec = processing_step_p->getMsFragmentationSpec();
     }
 
