@@ -125,7 +125,7 @@ bool
 ProgramWindow::openMassSpectrometryFileDlg(const QString &dir_name,
                                            bool full_in_memory)
 {
-  qDebug() << "The directory name is:" << dir_name;
+  //qDebug() << "The directory name is:" << dir_name;
 
   QFileDialog file_dialog(
     this,
@@ -1377,7 +1377,7 @@ ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
   // Let's see the usage count of the MsRunDataSetCstSPtr.
   // qDebug() << "Usage count:" << ms_run_data_set_sp.use_count();
 
-  //#if 0
+  #if 0
   // Let's control how the data loading process went.
 
   pappso::MsRunDataSetTreeCstSPtr ms_run_data_set_tree_csp =
@@ -1392,7 +1392,7 @@ ProgramWindow::finishedReadingMsRunData(MsRunDataSetSPtr ms_run_data_set_sp)
            << ms_run_data_set_tree_csp->depth()
            << "and the index node map has this number of items:"
            << index_node_map.size();
-  //#endif
+  #endif
 
   // We want to try the multi-visitor approach: a single visitor that contains a
   // vector of visitors. This is interesting because it makes reading the mass
@@ -2354,3 +2354,6 @@ ProgramWindow::showMsRunDataSetTableViewWnd(
 } // namespace minexpert
 
 } // namespace msxps
+
+
+
